RESOLV_CONF="/ram/resolv.conf"
NTPCONFDEF="/etc/ntp.conf.def"
NTPCONF="/ram/ntp.conf"
TZCONF="/ram/timezone"
LTCONF="/ram/localtime"

DEBUG_GLOBALS=""
if [ -f /ram/debug ]; then
    DEBUG="1" 
    DEBUG_GLOBALS="G" 
fi

exclude(){
    if [ ! -f $1 ]; then
	return;
    fi
    A=`awk '{ if( index($0,"#'"$2"'") == 0 ) { print $0; }}' $1`
    echo "${A}" > $1
}

excludeRaw(){
    if [ ! -f $1 ] || [ -z $2 ]; then
	return;
    fi
    A=`awk '{ if( index($0,"'"$2"'") == 0 ) { print $0; }}' $1`
    echo "${A}" > $1
}

selectByJsonPair(){
    if [ ! -f $1 ] || [ -z $2 ]; then
        return;
    fi
    awk -vvar1=${2} '{ if( index($0,var1) != 0 ) { print $0; }}' $1
}

excludeByJsonPair(){
    if [ ! -f $1 ] || [ -z $2 ]; then
        return;
    fi
    awk -vvar1=${2} '{ if( index($0,var1) == 0 ) { print $0; }}' $1
}

getMountPointByDevPath(){
    A=$(selectByJsonPair ${MOUNTS_CACHE} "\"devPath\":\"${1}\"")
    cnt=`echo "${A}" | wc -l`
    if [ "$cnt" != "1" ]; then
        return
    fi
    echo "$A" | sed -n 's/^.*"mountPath":"\(.*\)",.*$/\1/pg'
}

excludeByDevPath(){
    A=$(excludeByJsonPair ${1} "\"devPath\":\"${2}\"")
    echo "${A}" > ${1}
}

log()
{
  if [ "$DEBUG" != "1" ] && [ -z "$DEBUG_GLOBALS" ]; then
    return
  fi

  if [ "$DEBUG" == "0" ]; then
    return
  fi

  if [ -z "$LOG_FILE" ]; then
    LOG_FILE="/var/logs/$(basename "$0").log"
  fi

  if [ -n "$DEBUG_GLOBALS" ]; then
    echo `date +%H:%M.%S`" [$DEBUG_GLOBALS][$(basename "$0")] "$1 >> $LOG_FILE
    else 
    echo `date +%H:%M.%S`" [$(basename "$0")] "$1 >> $LOG_FILE
  fi

}

get_nvram_env()
{
    tmpVal=`fw_printenv $1 2>/dev/null`
    FW_ENV_RESULT=${tmpVal#*=}
}

read_nvram_var()
{
    get_nvram_env $1
    echo "$FW_ENV_RESULT"
}

# appending config line to current NTP config. 
# create default config if file not found
append_ntp_config()
{
    if [ ! -f $NTPCONF ]; then
        cat $NTPCONFDEF > $NTPCONF
	NTP_IP=$(read_nvram_var "ntpurl")
	if [ "$NTP_IP" != "" ]; then
	    echo "server $NTP_IP #manual" >> $NTPCONF
	fi
    fi

    echo $1 >> $NTPCONF
}

# update default gateways for interface "$1" with new default gw list "$2" using metric "$3"
update_default_gw_for_interface()
{
    if [ -n "$2" ]; then

	# get currently active routers
	WORK_ROUTERS=`ip route | sed -n "s/^default via \([^ ]*\) dev ${1}.*$/\1/p"`
	#log "WORK_ROUTERS = ${WORK_ROUTERS}"

	# list of routers to delete
	ROUTERS_TO_DEL="";
	for i in $WORK_ROUTERS
    	    do
        	isFound="0"
        	#checking work router
        	for j in $2
        	do
            	    #compape with new router
            	    if [ "${i}" = "${j}" ]; then
                	isFound="1"
                	break
            	    fi
        	done

        	if [ "$isFound" = "0" ]; then
            	    #store router $i for deletion
            	    ROUTERS_TO_DEL="${ROUTERS_TO_DEL}${i} "
        	fi
    	    done

	# add new routers
	for i in ${2}
	do
    	    #add router $i
    	    #log "add default gw ${i}, ${1}, ${3}"
    	    /sbin/route add default gw ${i} dev ${1} metric ${3}
	done

	# delete unneeded routers
	for i in $ROUTERS_TO_DEL
	do
    	    #DEL router ${i}
	    #log "del default gw ${i}"
    	    /sbin/route del default gw ${i}
	done

    fi
}
